@@ -16,7 +16,7 @@ FFI bindings for [hostfxr](https://github.com/dotnet/runtime/blob/main/docs/desi
 ## Related crates
 - [nethost-sys](https://crates.io/crates/nethost-sys) - bindings for the nethost library.
 - [coreclr-hosting-shared](https://crates.io/crates/coreclr-hosting-shared) - shared bindings between this crate and [nethost-sys](https://crates.io/crates/nethost-sys).
-- [netcorehost](https://crates.io/crates/netcorehost) - rusty wrapper over the hostfxr and hostfxr libraries.
+- [netcorehost](https://crates.io/crates/netcorehost) - rusty wrapper over the nethost and hostfxr libraries.
 
 ## Additional Information
 - [Hosting layer APIs](https://github.com/dotnet/core-setup/blob/master/Documentation/design-docs/hosting-layer-apis.md)
